@@ -57,10 +57,3 @@ class DependencyFixError(Exception):
     """
 
     pass
-
-
-class InvalidRequirementSpecifier(DependencySourceError):
-    """
-    A `DependencySourceError` specialized for the case of a non-PEP 440 requirements
-    specifier.
-    """
